==> haskell-tabular-0.2.2.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-E3mf3ECVuWqCqIaml40ALC
key: tabular-0.2.2.7-E3mf3ECVuWqCqIaml40ALC
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.SimpleText
    Text.Tabular.Csv Text.Tabular.Html Text.Tabular.Latex
abi: 648379c7d198bd69a6c876d378376940
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-E3mf3ECVuWqCqIaml40ALC
depends:
    base-4.9.1.0 csv-0.1.2-IUnXEueXED9ELeVORJac7R
    html-1.0.1.2-8wVtehjIxUEBYXzRus7033
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tabular-0.2.2.7-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU
key: tabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: 56ecd79702e8555ed1311007f33ae75d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.1/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-H6HQxZw1kjr7chsimRmSHU
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5
    html-1.0.1.2-Gz5RL5eVWKIJ2YfxLl6v89
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             csv-0.1.2-FTLnfLeG7H17CWj1kGbhS5=e7c836e2b810deed356ddc35bd7fb6ec
             html-1.0.1.2-Gz5RL5eVWKIJ2YfxLl6v89=42287eed8df22f4c4bed03249b0608ef
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
